==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/notify/translations/notify_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Evento</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>New messages</source>
        <translation>Nuovo messaggi</translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation>Notifica nuovi messaggi per la finestra inattiva</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Cambiamente dello status</translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation>Ignora i cambiament dello status da disponibile / occupato a disponibile / occupato</translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation>Non mostrare descrizioni dopo la conessione con server</translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation>Questa opzione disattiva comparsa delle notifiche con status dei contatti
durante primo colegamento Kadu con serwer</translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation>Notifica tutti i contatti</translation>
    </message>
    <message>
        <source>Connection error</source>
        <translation>Errore conessione</translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation>Contatto ha cambiato status a Accessibile</translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation>Contatto ha cambiato status a Occupato</translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation>Contatto ha cambiato status a Invisibile</translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation>Contatto ha cambiato status a Fuori line</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Nuovo chat</translation>
    </message>
    <message>
        <source>New message</source>
        <translation>Nuovo messaggio</translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation>Errore conessione</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation>&lt;b&gt;Errore:&lt;/b&gt; (%1) %2</translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation>Non posso trovare notifier per evento %1</translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation>Riporta nella &apos;Lista Notifiche&apos;</translation>
    </message>
    <message>
        <source>User list</source>
        <translation>Lista contatti</translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation>Riporta nella &apos;Lista Contatti&apos;</translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation>Lista notifiche</translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation>Cambiamento dello status</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ha cambiato status a &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ha cambiato status a &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/notify/translations/notify_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Evento</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>New messages</source>
        <translation>Nuovo messaggi</translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation>Notifica nuovi messaggi per la finestra inattiva</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Cambiamente dello status</translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation>Ignora i cambiament dello status da disponibile / occupato a disponibile / occupato</translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation>Non mostrare descrizioni dopo la conessione con server</translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation>Questa opzione disattiva comparsa delle notifiche con status dei contatti
durante primo colegamento Kadu con serwer</translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation>Notifica tutti i contatti</translation>
    </message>
    <message>
        <source>Connection error</source>
        <translation>Errore conessione</translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation>Contatto ha cambiato status a Accessibile</translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation>Contatto ha cambiato status a Occupato</translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation>Contatto ha cambiato status a Invisibile</translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation>Contatto ha cambiato status a Fuori line</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Nuovo chat</translation>
    </message>
    <message>
        <source>New message</source>
        <translation>Nuovo messaggio</translation>
    </message>
    <message>
        <source>Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Silent Mode when Away</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation>Errore conessione</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation>&lt;b&gt;Errore:&lt;/b&gt; (%1) %2</translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation>Non posso trovare notifier per evento %1</translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation>Riporta nella &apos;Lista Notifiche&apos;</translation>
    </message>
    <message>
        <source>User list</source>
        <translation>Lista contatti</translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation>Riporta nella &apos;Lista Contatti&apos;</translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation>Lista notifiche</translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation>Cambiamento dello status</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ha cambiato status a &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; ha cambiato status a &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
</context>
</TS>
